---
slug: /error-code-4000-4499
---

# 4000 ~ 4499

This error code range indicates general error codes.

## ERROR 4000 (HY000) : Common error

* seekdb error code: 4000

* Error cause: A general error.

* Solution: Contact technical support for assistance.

## ERROR 4001 (HY004) : Object type error

* seekdb error code: 4001

* Error cause: A type error.

* Solution: Contact technical support for assistance.

## ERROR 4003 (42000) : Array index out of range

* seekdb error code: 4003

* Error cause: An array index out of range.

* Solution: Contact technical support for assistance.

## ERROR 4004 (08S01) : Failed to listen to the port

* seekdb error code: 4004

* Error cause: The network is disconnected, so the listening service fails to start.

* Solution: Change to an idle port and restart the observer process.

## ERROR 4005 (HY000) : The object is initialized twice

* seekdb error code: 4005

* Error cause: The object is initialized twice.

* Solution: Contact technical support for assistance.

## ERROR 4005 (HY000) : User '%.*s'@'%.*s' is referenced as a definer account in a stored routine.

* seekdb error code: 5388

* Compatible MySQL error code: 4005

* Error cause: An orphan object is generated when an operation is performed on the user, or an orphan object is inherited.

* Solution: Check the permissions or delete the corresponding object.

## ERROR 4006 (HY000) : The object is not initialized

* seekdb error code: 4006

* Error cause: The object is not initialized.

* Solution: Contact technical support for assistance.

## ERROR 4006 (HY000) : Operation %.*s failed for '%.*s'@'%.*s' as it is referenced as a definer account in a stored routine.

* seekdb error code: 5389

* Compatible MySQL error code: 4006

* Error cause: An orphan object is generated when an operation is performed on the user, or an orphan object is inherited.

* Solution: Delete the corresponding object.

## ERROR 4008 ( HY000 ) : End of iteration

* seekdb error code: 4008

* Error cause: The iteration ends.

* Solution: Contact technical support for assistance.

## ERROR 4009 (58030 ) : IO error

* seekdb error code: 4009

* Error cause: The system call for reading or writing fails.

* Solution: Contact technical support for assistance.

## ERROR 4010 (HY000) : Wrong RPC command version

* seekdb error code: 4010

* Error cause: The RPC command version is incorrect.

* Solution: Contact technical support for assistance.

## ERROR 4012 ( HY000 ) : Timeout,  query has reached the maximum query timeout: %ld(us), maybe  you can adjust the session variable ob_query_timeout or query_timeout hint, and try again

* seekdb error code: 4012

* Error cause: The execution times out.

* Solution:

  * Optimize the performance to reduce the time spent.

  * Set a larger timeout.

  * Contact technical support for assistance.

## ERROR 4012 (HY000) : Task timeout and not executed

* seekdb error code: 4049

* Compatible MySQL error code: 4012

## ERROR 4012 (HY000) : RPC session not found

* seekdb error code: 4067

* Compatible MySQL error code: 4012

## ERROR 4012 (HY000) : RPC send error

* seekdb error code: 4121

* Compatible MySQL error code: 4012

## ERROR 4012 (HY000) : RPC post error

* seekdb error code: 4122

* Compatible MySQL error code: 4012

## ERROR 4012 (HY000) : Timeout

* seekdb error code: 4664

* Compatible MySQL error code: 4012

## ERROR 4012 (HY000) : Statement is timeout

* seekdb error code: 6004

* Compatible MySQL error code: 4012

## ERROR 4012 (25000) : Transaction timeout occurred, please rollback the transaction, set the variable ob_trx_timeout to a larger value and then restart the transaction

* seekdb error code: 6210

* Compatible MySQL error code: 4012

## ERROR 4012 (25000) : Statement timeout occurred, please set the variable ob_query_timeout to a larger value an then restart the statement

* seekdb error code: 6212

* Compatible MySQL error code: 4012

## ERROR 4012 (25000) : Transaction result isunknown

* seekdb error code: 6225

* Compatible MySQL error code: 4012

## ERROR 4012 (25000) : transaction rpc timeout

* seekdb error code: 6230

* Compatible MySQL error code: 4012

## ERROR 4013 (HY001) : No memory or reach tenant memory limit

* seekdb error code: 4013

* Error cause: The memory allocation fails.
  * The physical memory is exhausted.
  * The memory allocated in a single operation exceeds 4 GB.
  * The memory usage of CTX, tenant, or server reaches the upper limit.

* Solution: Contact technical support for assistance.

## ERROR 4014 (HY001) : Inner state error

* seekdb error code: 4014

* Error cause: An internal state error.

* Solution: Contact technical support for assistance.

## ERROR 4015 (HY000) : System error

* seekdb error code: 4015

* Error cause: An internal error code.

* Solution: Contact technical support for assistance.

## ERROR 4016 (HY000) : Internal error

* seekdb error code: 4016

* Error cause: An internal error code.

* Solution: Contact technical support for assistance.

## ERROR 4017 (HY000) : Entry already exist

* seekdb error code: 4017

* Error cause: The data already exists.

* Solution: Contact technical support for assistance.

## ERROR 4018 (HY000) : Entry not exist

* seekdb error code: 4018

* Error cause: The data does not exist.

* Solution: Contact technical support for assistance.

## ERROR 4019 (HY000) : Size overflow

* seekdb error code: 4019

* Cause: The space overflows.

* Solution: Contact technical support.

## ERROR 4020 (HY000) : Reference count is not zero

* seekdb error code: 4020

* Cause: The reference count is not zero.

* Solution: Contact technical support.

## ERROR 4021 (HY000) : Conflict value

* seekdb error code: 4021

* Cause: A logical error occurs in the base library, which is generally caused by a code error.

* Solution: Contact technical support.

## ERROR 4022 (HY000) : Item not set

* seekdb error code: 4022

* Cause: The value is not set.

* Solution: Contact technical support.

## ERROR 4023 (HY000) : Try again

* seekdb error code: 4023

* Cause: The operation needs to be retried.

* Solution: Retry the operation, or contact technical support.

## ERROR 4024 (HY000) : Buffer not enough

* seekdb error code: 4024

* Cause: The space is insufficient.

* Solution: Contact technical support.

## ERROR 4025 (HY000) : Partial failed

* seekdb error code: 4025

* Cause: In batch tasks, some operations are successful and some are failed.

* Solution: Contact technical support.

## ERROR 4026 (02000) : Nothing to read

* seekdb error code: 4026

* Cause: No data is available for reading.

* Solution: Contact technical support.

## ERROR 4027 (HY000) : User account `%.*s`@`%.*s` is directly or indirectly granted to the role `%.*s`@`%.*s`. The GRANT would create a loop

* seekdb error code: 5373

* MySQL compatible error code: 4027

* Cause: The user account %.*s@%.*s is directly or indirectly granted to the role %.*s@%.*s, which creates a loop in the GRANT command.
* Solution: Check the authorization relationships between the user account and the role to ensure that no loop exists.

## ERROR 4028 (HY000) : Log entry not continuous

* seekdb error code: 4028

* Cause: The file IDs are not continuous.

* Solution: Contact technical support.

## ERROR 4029 (HY000) : Schema error

* seekdb error code: 4029

* Cause: The schema cannot be obtained.

* Solution: Contact technical support.

## ERROR 4031 (HY004) : Unknown object

* seekdb error code: 4031

* Cause: The object is unknown.

* Solution: Contact technical support.

## ERROR 4033 (HY000) : Serialize error

* seekdb error code: 4033

* Cause: The serialization fails.

* Solution: Contact technical support.

## ERROR 4034 (HY000) : Deserialize error

* seekdb error code: 4034

* Cause: The deserialization fails.

* Solution: Contact technical support.

## ERROR 4035 (HY000) : Asynchronous IO error

* seekdb error code: 4035

* Cause: A system call related to asynchronous I/O fails.

* Solution: Contact technical support.

## ERROR 4036 (HY000) : Need retry

* seekdb error code: 4036

* Cause: The operation needs to be retried.

* Solution: Retry the operation, or contact technical support.

## ERROR 4037 (HY000) : Too many sstable

* seekdb error code: 4037

* Cause: Too many SSTables are generated, which is generally caused by frequent dumps.

* Solution: Expand the storage capacity to reduce the pressure on a single server, or contact technical support.

## ERROR 4039 (HY000) : Request has killed by sql throttle

* seekdb error code: 4039

* Cause: The SQL statement is throttled.

* Solution: Contact technical support.

## ERROR 4045 (HY000) : pushdown status changed

* seekdb error code: 4045

* Cause: An internal error occurs.

* Solution: Contact technical support.

## ERROR 4046 (HY000) : Storage schema is not valid

* seekdb error code: 4046

* Cause: The storage schema is invalid.

* Solution: Contact technical support.

## ERROR 4047 (HY000) : Medium compaction info is not valid

* seekdb error code: 4047

* Cause: The medium info is invalid.

* Solution: Contact technical support.

## ERROR 4048 (HY000) : Not registered

* seekdb error code: 4048

* Cause: An internal error occurs.

* Solution: Contact technical support.

## ERROR 4050 (HY000) : Not the object

* seekdb error code: 4050

* Cause: The object does not match.

* Solution: Contact technical support.

## ERROR 4052 (HY000) : Corrupted log entry

* seekdb error code: 4052

* Cause: The log entry is corrupted, which is generally caused by hardware or disk errors that result in incorrect log data.

* Solution: Contact the DBA to troubleshoot the hardware issue, or contact technical support.

## ERROR 4055 (HY000) : Invalid entry

* seekdb error code: 4055

* Cause: An internal state error occurs.

* Solution: Contact technical support.

## ERROR 4057 (HY000) : Decimal overflow warning

* seekdb error code: 4057

* Cause: The data precision exceeds the limit.

* Solution: Reduce the input data precision.

## ERROR 4058 (HY000) : Decimal overflow error

* seekdb error code: 4058

* Cause: The data precision exceeds the limit.

* Solution: Reduce the input data precision.

## ERROR 4060 (HY000) : Divide error

* seekdb error code: 4060

* Cause: A division error occurs.

* Solution: Contact technical support.

## ERROR 4061 (HY000) : Not a decimal

* seekdb error code: 4061

* Cause: A type error occurs.

* Solution: Contact technical support.

## ERROR 4062 (HY104) : Decimal precision error

* seekdb error code: 4062

* Cause: A number precision error occurs.

* Solution: Contact technical support.

## ERROR 4063 (HY000) : Empty range

* seekdb error code: 4063

* Cause: The query range for the `LIKE` condition cannot be obtained.

* Solution: Contact technical support.

## ERROR 4064 (HY000) : Session killed

* seekdb error code: 4064

* Error reason: The session is terminated.

* Solution: Contact your system administrator or database administrator.

## ERROR 4068 (HY000) : Invalid log

* seekdb error code: 4068

* Error reason: The log is invalid.

* Solution: Contact technical support.

## ERROR 4070 (HY000) : Invalid data

* seekdb error code: 4070

* Error reason: The data is invalid.

* Solution: Contact technical support.

## ERROR 4071 (HY000) : Already done

* seekdb error code: 4071

* Error reason: The operation is completed.

* Solution: Contact technical support.

## ERROR 4072 (HY000) : Operation canceled

* seekdb error code: 4072

* Error reason: The operation is canceled.

* Solution: Contact technical support.

## ERROR 4074 (HY000) : Log not aligned

* seekdb error code: 4074

* Error reason: The log is not aligned.

* Solution: Contact technical support.

## ERROR 4075 (HY000) : Log entry missed

* seekdb error code: 4075

* Error reason: The log entry is not found.

* Solution: Contact technical support.

## ERROR 4076 (HY000) : Need wait

* seekdb error code: 4076

* Error reason: Waiting is required.

* Solution: Contact technical support.

## ERROR 4077 (0A000) : Not implemented feature

* seekdb error code: 4077

* Error reason: The feature is not implemented.

* Solution: Contact technical support.

## ERROR 4080 (HY013) : exceed memory limit

* seekdb error code: 4080

* Error reason: Internal error code. It is mainly used for the condition judgment of the intermediate result of the SQL operator to be stored in the disk.

* Solution: The memory limit exceeded may be caused by different reasons. You need to first determine the reason.

## ERROR 4084 (02000) : No result

* seekdb error code: 4084

* Error reason: The value of the configuration item is not found.

* Solution: Contact technical support.

## ERROR 4085 (HY000) : Queue overflow

* seekdb error code: 4085

* Error reason: The queue length is exceeded.

* Solution: Contact technical support.

## ERROR 4090 (HY000) : Table log_id range no continuous

* seekdb error code: 4090

* Error reason: The log ID ranges of SSTables in a partition are not continuous.

* Solution: Contact technical support.

## ERROR 4104 (HY000) : Initialize error

* seekdb error code: 4104

* Error reason: The initialization fails.

* Solution: Contact technical support.

## ERROR 4105 (HY000) : Rowkey order error

* seekdb error code: 4105

* Error reason: The primary key is out of order.

* Solution: Contact technical support.

## ERROR 4107 (HY000) : block switched when fill commitlog

* seekdb error code: 4107

* Error reason: The `buffer` used by `Group Commit` needs to be switched.

* Solution: Contact technical support.

## ERROR 4109 (HY000) : Server state or role not the same as expected

* seekdb error code: 4109

* Error reason: The state is inconsistent.

* Solution: Contact technical support.

## ERROR 4111 (HY000) : block need freeze

* seekdb error code: 4111

* Error reason: The block needs to be frozen.

* Solution: Contact technical support.

## ERROR 4112 (HY000) : block frozen

* seekdb error code: 4112

* Error reason: The block has been frozen.

* Solution: Contact technical support.

## ERROR 4113 (HY000) : In FATAL state

* seekdb error code: 4113

* Error reason: The state is invalid.

* Solution: Contact technical support.

## ERROR 4114 (08S01) : In STOP state

* seekdb error code: 4114

* Error reason: seekdb is in the Stop process.

* Solution: If the error persists for a long time, contact technical support.

## ERROR 4119 (08000) : RPC packet to send too long

* seekdb error code: 4119

* Error reason: The length of the RPC packet exceeds the limit.

* Solution: Contact technical support.

## ERROR 4120 (HY000) : Log too large

* seekdb error code: 4120

* Error reason: The log is too large.

* Solution: Contact technical support.

## ERROR 4123 (08000) : Libeasy error

* seekdb error code: 4123

* Error reason: The network initialization fails.

* Solution: Contact your system administrator or database administrator.

## ERROR 4124 (HY000) : Connect error

* seekdb error code: 4124

* Error reason: The server connection cannot be established.

* Solution: Contact your system administrator or database administrator.

## ERROR 4128 (HY000) : RPC packet is invalid

* seekdb error code: 4128

* Error reason: The RPC packet is invalid.

* Solution: Contact your system administrator or database administrator.

## ERROR 4138 (HY000) : Request to read too old versioned data

* seekdb error code: 4138

* Error reason: The data version is too old.

* Solution: Execute the statement again or increase the value of the undo_retention parameter.

## ERROR 4143 (42000) : Version not match

* seekdb error code: 4143

* Error reason: The versions are inconsistent.

* Solution: Contact technical support.

## ERROR 4147 (HY000) : Invalid config

* seekdb error code: 4147

* Error reason: The configuration is invalid.

* Solution: Contact technical support.

## ERROR 4150 (42000) : Min value

* seekdb error code: 4150

* Error reason: The minimum special value of the internal table is accessed.

* Solution: Contact technical support.

## ERROR 4151 (42000) : Max value

* seekdb error code: 4151

* Error reason: The maximum special value of the internal table is accessed.

* Solution: Contact technical support.

## ERROR 4152 (42000) : Null value

* seekdb error code: 4152

* Error reason: The null value of the internal table is accessed.

* Solution: Contact technical support.

## ERROR 4154 (HY000) : Internal SQL client error

* seekdb error code: 4154

* Error cause: An internal error occurred in the SQL client.

* Solution: Contact technical support.

## ERROR 4161 (42000) : Invalid argument num

* seekdb error code: 4161

* Error cause: The number of arguments is invalid.

* Solution: Check the argument list or contact technical support.

## ERROR 4162 (HY000) : reserved lease not enough

* seekdb error code: 4162

* Error cause: The reserved lease time is insufficient.

* Solution: Contact technical support.

## ERROR 4165 (HY000) : Empty result

* seekdb error code: 4165

* Error cause: The result set is empty.

* Solution: Contact technical support.

## ERROR 4168 (HY000) : Invalid log module id

* seekdb error code: 4168

* Error cause: The log module ID is invalid.

* Solution: Contact technical support.

## ERROR 4169 (HY000) : Unknown module name. Invalid Setting:'%.\*s'. Syntax:parMod.subMod:level, parMod.subMod:level

* seekdb error code: 4169

* Error cause: The log module name is invalid, which is caused by incorrect module name setting.

* Solution: Contact technical support.

## ERROR 4170 (HY000) : Invalid level. Invalid setting:'%.\*s'. Syntax:parMod.subMod:level, parMod.subMod:level

* seekdb error code: 4170

* Error cause: The log level is invalid, which is caused by incorrect log level setting.

* Solution: Contact technical support.

## ERROR 4171 (HY000) : Syntax to set log_level error. Invalid setting:'%.\*s'. Syntax:parMod.subMod:level, parMod.subMod:level

* seekdb error code: 4171

* Error cause: The log level setting syntax is invalid, which is caused by incorrect log level setting.

* Solution: Contact technical support.

## ERROR 4172 (HY000) : Index out of range

* seekdb error code: 4172

* Error cause: The index is out of range.

* Solution: Contact technical support.

## ERROR 4175 (42000) : Out of range

* seekdb error code: 4175

* Error cause: The value is out of range.

* Solution: Contact technical support.

## ERROR 4177 (42000) : Schema version too old

* seekdb error code: 4177

* Error cause: The local schema version is outdated.

* Solution: Contact technical support.

## ERROR 4179 (HY000) : %s not allowed

* seekdb error code: 4179

* Error cause: The feature is not supported.

* Solution: Contact technical support.

## ERROR 4180 (HY000) : No empty entry

* seekdb error code: 4180

* Error cause: The data item is not empty.

* Solution: Contact technical support.

## ERROR 4181 (42S01) : Already exist

* seekdb error code: 4181

* Error cause: The item already exists in the position cache.

* Solution: Contact technical support.

## ERROR 4182 (HY000) : Value not found

* seekdb error code: 4182

* Error cause: The value is not found.

* Solution: Contact technical support.

## ERROR 4183 (HY000) : Key out of range

* seekdb error code: 4183

* Error cause: The key is out of range.

* Solution: Contact technical support.

## ERROR 4184 (53100) : ChunkServer out of disk space

* seekdb error code: 4184

* Error cause: The disk space is full.

* Solution: Add servers to expand the capacity, or contact technical support.

## ERROR 4185 (HY000) : Column group \'%.*s\' not found

* seekdb error code: 4185

* Error cause: The specified column group is not found.
* Solution: Check whether the specified column group name is correct and ensure that the column group exists or use the correct column group name.

## ERROR 4186 (HY000) : ChunkServer failed to get compress library

* seekdb error code: 4186

* Error cause: The compression library is not found.

* Solution: Contact technical support.

## ERROR 4187 (HY000) : Item not match

* seekdb error code: 4187

* Error cause: The value does not match.

* Solution: Contact technical support.

## ERROR 4189 (HY000) : the macro block type does not exist

* seekdb error code: 4189

* Error cause: The macro block type does not exist.

* Solution: Contact technical support.

## ERROR 4191 (HY000) : partition group is removed

* seekdb error code: 4191

* Error cause: The partition is deleted.

* Solution: No action is required.

## ERROR 4192 (42000) : ddl task executes too much time

* seekdb error code: 4192
* Error cause: The DDL task execution time is too long.
* Solution: Check whether the execution time of the DDL operation meets the expected value. If not, contact technical support.

## ERROR 4200 (HY000) : hash map/set entry exist

* seekdb error code: 4200

* Error cause: The `HASH` value already exists.

* Solution: Contact technical support.

## ERROR 4201 (HY000) : hash map/set entry not exist

* seekdb error code: 4201

* Error cause: The `HASH` value does not exist.

* Solution: Contact technical support.

## ERROR 4204 (HY000) : hash map/set get timeout

* seekdb error code: 4204

* Error cause: The `HASH` operation times out.

* Solution: Contact technical support.

## ERROR 4205 (HY000) : hash map/set retry

* seekdb error code: 4205

* Error cause: The `HASH` operation needs to be retried.

* Solution: Contact technical support.

## ERROR 4206 (HY000) : hash map/set full

* seekdb error code: 4206

* Error cause: The `HASH` operation is full.

* Solution: Contact technical support.

## ERROR 4208 (HY000) : wait next packet timeout

* seekdb error code: 4208

* Error cause: The timeout occurs while waiting for the next packet.

* Solution: Contact technical support.

## ERROR 4210 (HY000) : prepare major freeze failed

* seekdb error code: 4210

* Error reason: The preparation for a major freeze failed.

* Solution: Contact technical support.

## ERROR 4211 (HY000) : commit major freeze failed

* seekdb error code: 4211

* Error reason: The commit for a major freeze failed.

* Solution: Contact technical support.

## ERROR 4212 (HY000) : abort major freeze failed

* seekdb error code: 4212

* Error reason: The abort for a major freeze failed.

* Solution: Contact technical support.

## ERROR 4213 (HY000) : last major freeze not finish", "%s

* seekdb error code: 4213

* Error reason: The last major freeze is not completed.

* Solution: Wait for the major freeze to complete, and then start a new major freeze.

## ERROR 4215 (HY000) : wait major freeze response timeout

* seekdb error code: 4215

* Error reason: The major freeze response timed out.

* Solution: Contact technical support.

## ERROR 4216 (HY000) : curl error

* seekdb error code: 4216

* Error reason: The `libcurl` access failed.

* Solution: Contact technical support.

## ERROR 4217 (HY000) : Major freeze not allowed now

* seekdb error code: 4217

* Error reason: A major freeze is not allowed at this time.

* Solution: The system may be upgrading or in another process, and a major freeze is not allowed.

## ERROR 4218 (HY000) : prepare freeze failed

* seekdb error code: 4218

* Error reason: The preparation for a freeze failed.

* Solution: Contact technical support.

## ERROR 4220 (HY000) : Inactive sql client, only read allowed

* seekdb error code: 4220

* Error reason: The SQL client is invalid.

* Solution: Contact technical support.

## ERROR 4221 (HY000) : Inactive rpc proxy, can not send RPC request

* seekdb error code: 4221

* Error reason: The RPC client is not initialized.

* Solution: Contact technical support.

## ERROR 4222 (42000) : Interval with year or month can not be converted to microseconds

* seekdb error code: 4222

* Error reason: The time type conversion failed.

* Solution: Contact technical support.

## ERROR 4223 (42000) : Interval has too many datetime parts

* seekdb error code: 4223

* Error reason: The time type conversion failed.

* Solution: Contact technical support.

## ERROR 4225 (HY000) : Partition entry not exists

* seekdb error code: 4225

* Error reason: The partition does not exist.

* Solution: Contact technical support.

## ERROR 4233 (HY000) : smaller than container lower bound

* seekdb error code: 4233

* Error reason: The value is smaller than the lower bound of the container.

* Solution: Contact technical support.

## ERROR 4234 (HY000) : bigger than container upper bound

* seekdb error code: 4234

* Error reason: The value is larger than the upper bound of the container.

* Solution: Contact technical support.

## ERROR 4236 (HY000) : ObConfig return error code

* seekdb error code: 4236

* Error reason: The access to the Config Server service failed.

* Solution: Check the `obconfig_url` parameter to determine whether the Config Server service is working properly, and contact technical support.

## ERROR 4239 (HY000) : Can not use merge join to join the tables without join conditions

* seekdb error code: 4239

* Error reason: An internal error occurred.

* Solution: Contact technical support.

## ERROR 4240 (HY000) : No join order generated

* seekdb error code: 4240

* Error reason: An internal error occurred.

* Solution: Contact technical support.

## ERROR 4241 (HY000) : No join path generated

* seekdb error code: 4241

* Error reason: An internal error occurred.

* Solution: Contact technical support.

## ERROR 4242 (HY000) : Schema error

* seekdb error code: 4242

* Error reason: The execution endpoint failed to obtain the schema.

* Solution: Contact technical support.

## ERROR 4243 (HY000) : file not opened

* seekdb error code: 4243

* Error reason: The file is not opened.

* Solution: Contact technical support.

## ERROR 4244 (HY000) : Timer task has been scheduled

* seekdb error code: 4244

* Error reason: The timer task was already registered.

* Solution: Contact technical support.

## ERROR 4245 (HY000) : Timer task has not been scheduled

* seekdb error code: 4245

* Error reason: The timer task was not registered.

* Solution: Contact technical support.

## ERROR 4246 (HY000) : parse debug sync string error

* seekdb error code: 4246

* Error reason: The `debug_sync` string does not conform to the syntax.

* Solution: Contact technical support.

## ERROR 4247 (HY000) : unknown debug sync point

* seekdb error code: 4247

* Error reason: The `debug sync` point does not exist.

* Solution: Contact technical support.

## ERROR 4250 (HY000) : module is not running

* seekdb error code: 4250

* Error reason: The module is not running.

* Solution: Contact technical support.

## ERROR 4251 (HY000) : partition not valid

* seekdb error code: 4251

* Error reason: The partition is invalid.

* Solution: Contact technical support.

## ERROR 4253 (HY000) : Comment for tenant is too long (max = %ld)

* seekdb error code: 4253

* Cause: The `COMMENT` clause in the DDL statement is too long.

* Solution: Reduce the length of the `COMMENT` clause in the DDL statement.

## ERROR 4257 (HY000) : compress data or decompress data failed

* seekdb error code: 4257

* Cause: Data compression or decompression failed, possibly due to data corruption.

* Solution: Contact the DBA to check for hardware issues, replace faulty machines, or perform data recovery.

## ERROR 4263 (HY000) : Minor freeze not allowed now

* seekdb error code: 4263

* Cause: Minor version freezing is temporarily not allowed.

* Solution: Contact technical support for assistance.

## ERROR 4264 (HY000) : Log out of disk space

* seekdb error code: 4264

* Cause: The log disk is full.

* Solution: Contact technical support for assistance.

## ERROR 4265 (HY000) : Rpc connect error

* seekdb error code: 4265

* Cause: The RPC connection failed.

* Solution: Contact technical support for assistance.

## ERROR 4266 (HY000) : minor merge not allow

* seekdb error code: 4266

* Cause: Minor compaction is temporarily not allowed.

* Solution: Contact technical support for assistance.

## ERROR 4270 (HY000) : Working partition entry does not exists

* seekdb error code: 4270

* Cause: The partition status is abnormal.

* Solution: Contact technical support for assistance.

## ERROR 4271 (HY000) : LIBEASY reach memory limit

* seekdb error code: 4271

* Cause: The memory occupied by untransmitted packets in LIBEASY exceeds the limit.

* Solution: Contact technical support for assistance.

## ERROR 4273 (HY000) : free memblock in cache is not enough

* seekdb error code: 4273

* Cause: The number of free memory blocks in the cache is insufficient.

* Solution: Try to adjust the memory or reduce the pressure, or contact technical support for assistance.

## ERROR 4274 (HY000) : sync wash memblock timeout

* seekdb error code: 4274

* Cause: The memory block release timed out.

* Solution: Contact technical support for assistance.

## ERROR 4278 (HY000) : last log is not complete

* seekdb error code: 4278

* Cause: The last log is incomplete, possibly due to a power outage or sudden failure.

* Solution: Restart the OBServer or contact technical support for assistance.

## ERROR 4279 (HY000) : table is deleted

* seekdb error code: 4279

* Cause: The table has been deleted.

* Solution: Check whether the SQL statement accesses the deleted table.

## ERROR 4280 (HY000) : version range not continues

* seekdb error code: 4280

* Cause: The version range is not continuous.

* Solution: Contact technical support for assistance.

## ERROR 4281 (HY000) : io buffer is invalid

* seekdb error code: 4281

* Cause: The I/O buffer is invalid.

* Solution: Contact technical support for assistance.

## ERROR 4282 (HY000) : partition is removed

* seekdb error code: 4282

* Cause: The partition has been deleted.

* Solution: Check whether the deleted partition is operated on, or contact technical support for assistance.

## ERROR 4286 (HY000) : major sstable may has been merged

* seekdb error code: 4286

* Cause: The baseline has been merged.

* Solution: Contact technical support for assistance.

## ERROR 4287 (HY000) : minor sstable version range cross

* seekdb error code: 4287

* Cause: The minor SSTable version range overlaps.

* Solution: Contact technical support for assistance.

## ERROR 4288 (HY000) : memtable cannot minor merge

* seekdb error code: 4288

* Cause: The MemTable cannot be minor merged.

* Solution: Contact technical support for assistance.

## ERROR 4289 (HY000) : task exist

* seekdb error code: 4289

* Cause: The task is duplicated.

* Solution: Contact technical support for assistance.

## ERROR 4290 (HY000) : cannot allocate disk space

* seekdb error code: 4290

* Cause: The disk space is insufficient.

* Solution: Expand the disk space, or contact technical support for assistance.

## ERROR 4297 (HY000) : name is already used by an existing object

* seekdb error code: 4297

* Cause: The name conflicts with that of another object in the same namespace.

* Solution: Change the object name to one that is not used by any other object in the namespace.

## ERROR 4298 (HY000) : %s does not exist

* seekdb error code: 4298

* MySQL compatible error code: 4298

* Cause: The object to be operated on does not exist.

* Solution: Ensure that the sequence name is correct and that you have the required privileges to operate on the sequence.

## ERROR 4300 (HY000) : invalid sequence name

* seekdb error code: 4300

* Cause: The sequence name is invalid.

* Solution: Change the sequence name.

## ERROR 4301 (HY000) : duplicate MAXVALUE/NOMAXVALUE specifications

* seekdb error code: 4301

* Cause: The `MAXVALUE` or `NOMAXVALUE` clause is specified more than once.

* Solution: Remove the duplicate `MAXVALUE` or `NOMAXVALUE` clause.

## ERROR 4302 (HY000) : duplicate MINVALUE/NOMINVALUE specifications

* seekdb error code: 4302

* Cause: The `MINVALUE` or `NOMINVALUE` clause is specified more than once.

* Solution: Remove the duplicate `MINVALUE` or `NOMINVALUE` clause.

## ERROR 4303 (HY000) : duplicate CYCLE/NOCYCLE specifications

* seekdb error code: 4303

* Cause: The `CYCLE` or `NOCYCLE` clause is specified more than once.

* Solution: Remove the duplicate `CYCLE` or `NOCYCLE` clause.

## ERROR 4304 (HY000) : duplicate CACHE/NOCACHE specifications

* seekdb error code: 4304

* Cause: The `CACHE` or `NOCACHE` clause is specified more than once.

* Solution: Remove the duplicate `CACHE` or `NOCACHE` clause.

## ERROR 4305 (HY000) : duplicate ORDER/NOORDER specifications

* seekdb error code: 4305

* Error cause: The `ORDER` or `NOORDER` option is specified more than once.

* Solution: Remove the duplicate `ORDER` or `NOORDER` option.

## ERROR 4306 (HY000) : conflicting MAXVALUE/NOMAXVALUE specifications

* seekdb error code: 4306

* Error cause: The `MAXVALUE` and `NOMAXVALUE` options are specified in a conflicting manner.

* Solution: Remove the conflicting `MAXVALUE` or `NOMAXVALUE` option.

## ERROR 4307 (HY000) : conflicting MINVALUE/NOMINVALUE specifications

* seekdb error code: 4307

* Error cause: The `MINVALUE` and `NOMINVALUE` options are specified in a conflicting manner.

* Solution: Remove the conflicting `MINVALUE` or `NOMINVALUE` option.

## ERROR 4308 (HY000) : conflicting CYCLE/NOCYCLE specifications

* seekdb error code: 4308

* Error cause: The `CYCLE` and `NOCYCLE` options are specified in a conflicting manner.

* Solution: Remove the conflicting `CYCLE` or `NOCYCLE` option.

## ERROR 4309 (HY000) : conflicting CACHE/NOCACHE specifications

* seekdb error code: 4309

* Error cause: The `CACHE` and `NOCACHE` options are specified in a conflicting manner.

* Solution: Remove the conflicting `CACHE` or `NOCACHE` option.

## ERROR 4310 (HY000) : conflicting ORDER/NOORDER specifications

* seekdb error code: 4310

* Error cause: The `ORDER` and `NOORDER` options are specified in a conflicting manner.

* Solution: Remove the conflicting `ORDER` or `NOORDER` option.

## ERROR 4311 (HY000) : cannot alter starting sequence number

* seekdb error code: 4311

* Error cause: The `START WITH` option of an auto-increment column cannot be modified.

* Solution: Do not modify the `START WITH` option.

## ERROR 4312 (HY000) : duplicate INCREMENT BY specifications

* seekdb error code: 4312

* Error cause: The `INCREMENT BY` option is specified more than once.

* Solution: Remove the duplicate `INCREMENT BY` option.

## ERROR 4313 (HY000) : duplicate START WITH specifications

* seekdb error code: 4313

* Error cause: The `START WITH` option is specified more than once.

* Solution: Remove the duplicate `START WITH` option.

## ERROR 4314 (HY000) : no options specified for ALTER SEQUENCE

* seekdb error code: 4314

* Error cause: No options are specified for the `ALTER SEQUENCE` statement.

* Solution: A statement with no options is meaningless.

## ERROR 4315 (HY000) : sequence number not allowed here

* seekdb error code: 4315

* Error cause: An auto-increment column cannot be specified here.

* Solution: Remove the auto-increment column.

## ERROR 4316 (HY000) : sequence does not exist

* seekdb error code: 4316

* Error cause: The auto-increment column does not exist or you do not have the required permissions.

* Solution: Ensure that the auto-increment column name is correct and that you have the required permissions.

## ERROR 4317 (HY000) : sequence parameter %s must be an integer

* seekdb error code: 4317

* Error cause: The parameter specified for the `CREATE SEQUENCE` or `ALTER SEQUENCE` statement must be an integer.

* Solution: Specify an integer value for the specified parameter when you create or modify an auto-increment column.

## ERROR 4318 (HY000) : INCREMENT must be a nonzero integer

* seekdb error code: 4318

* Error cause: The value of the `INCREMENT` option must be a non-zero integer.

* Solution: Specify a non-zero integer value for the `INCREMENT` option.

## ERROR 4319 (HY000) : sequence parameter exceeds maximum size allowed

* seekdb error code: 4319

* Error cause: The value of the parameter of the auto-increment column exceeds the maximum allowed value.

* Solution: Specify a parameter with a value that does not exceed the maximum allowed value.

## ERROR 4320 (HY000) : MINVALUE must be less than MAXVALUE

* seekdb error code: 4320

* Error cause: In the `CREATE SEQUENCE` or `ALTER SEQUENCE` statement, the value of the `MINVALUE` option must be less than the value of the `MAXVALUE` option.

* Solution: Specify a value for the `MINVALUE` option that is less than the value of the `MAXVALUE` option.

## ERROR 4321 (HY000) : INCREMENT must be less than MAXVALUE minus MINVALUE

* seekdb error code: 4321

* Error cause: In the `CREATE SEQUENCE` or `ALTER SEQUENCE` statement, the value of the `INCREMENT` option must be less than the difference between the values of the `MAXVALUE` and `MINVALUE` options.

* Solution: Specify a value for the `INCREMENT` option that is less than the difference between the values of the `MAXVALUE` and `MINVALUE` options.

## ERROR 4322 (HY000) : START WITH cannot be less than MINVALUE

* seekdb error code: 4322

* Error cause: In the `CREATE SEQUENCE` or `ALTER SEQUENCE` statement, the value of the `START WITH` option cannot be less than the value of the `MINVALUE` option.

* Solution: Ensure that the value of the `START WITH` option is not less than the value of the `MINVALUE` option.

## ERROR 4323 (HY000) : MINVALUE cannot be made to exceed the current value

* seekdb error code: 4323

* Error cause: The value of the `MINVALUE` option is greater than the current value.

* Solution: Ensure that the value of the `MINVALUE` option is less than the current value.

## ERROR 4324 (HY000) : START WITH cannot be more than MAXVALUE

* seekdb error code: 4324

* Error cause: The value of the `START WITH` option is greater than the value of the `MAXVALUE` option.

* Solution: Ensure that the value of the `START WITH` option is less than the value of the `MAXVALUE` option.

## ERROR 4325 (HY000) : MAXVALUE cannot be made to be less than the current value

* seekdb error code: 4325

* Error cause: The value of the `MAXVALUE` option is less than the current value.

* Solution: Ensure that the value of the `MAXVALUE` option is greater than the current value.

## ERROR 4326 (HY000) : the number of values to CACHE must be greater than 1

* seekdb error code: 4326

* Error reason: The value of the `CACHE` clause must be greater than `1`.

* Solution: Specify a value greater than `1` for the `CACHE` clause.

## ERROR 4327 (HY000) : sequence option value out of range

* seekdb error code: 4327

* Error reason: The value of the parameter in the `CREATE SEQUENCE` or `ALTER SEQUENCE` statement is out of the specified range.

* Solution: Specify a value within the specified range.

## ERROR 4328 (HY000) : number to CACHE must be less than one cycle

* seekdb error code: 4328

* Error reason: The value of the `CACHE` clause must be less than one cycle.

* Solution: Increase the cycle or specify a smaller value for the `CACHE` clause.

## ERROR 4329 (HY000) : descending sequences that CYCLE must specify MINVALUE

* seekdb error code: 4329

* Error reason: The `MINVALUE` clause must be specified for a descending sequence that cycles.

* Solution: Recreate the sequence and specify the `MINVALUE` clause.

## ERROR 4330 (HY000) : ascending sequences that CYCLE must specify MAXVALUE

* seekdb error code: 4330

* Error reason: The `MAXVALUE` clause must be specified for an ascending sequence that cycles.

* Solution: Recreate the sequence and specify the `MAXVALUE` clause.

## ERROR 4331 (HY000) : sequence %s no longer exists

* seekdb error code: 4331

* Error reason: The sequence does not exist.

* Solution: Recreate the sequence.

## ERROR 4332 (HY000) : sequence exceeds %s and cannot be instantiated

* seekdb error code: 4332

* Error reason: The value of the sequence has reached the upper limit and cannot be obtained.

* Solution: Change the sequence to allow new values to be requested.

## ERROR 4333 (HY000) : divisor is equal to zero

* seekdb error code: 4333

* Error reason: The divisor is equal to zero.

* Solution: Contact technical support.

## ERROR 4337 (HY000) : store directory structure error

* seekdb error code: 4337

* Error reason: The store directory structure failed.

* Solution: Contact technical support.

## ERROR 4338 (HY000) : open twice

* seekdb error code: 4338

* Error reason: The file was opened twice.

* Solution: Contact technical support.

## ERROR 4339 (HY000) : raid super block not match

* seekdb error code: 4339

* Error reason: The super block is incorrect.

* Solution: This error may be caused by a hardware failure. Check the disk or contact technical support.

## ERROR 4340 (HY000) : not opened

* seekdb error code: 4340

* Error reason: The file is not opened.

* Solution: Contact technical support.

## ERROR 4341 (HY000) : target module is not in service

* seekdb error code: 4341

* Error reason: The weak read service is not started.

* Solution: Contact technical support.

## ERROR 4342 (HY000) : raid disk not in normal status

* seekdb error code: 4342

* Error reason: The disk status is abnormal.

* Solution: Contact technical support.

## ERROR 4343 (HY000) : tenant schema is not full

* seekdb error code: 4343

* Error reason: The local schema version is outdated.

* Solution: Contact technical support.

## ERROR 4344 (HY000) : invalid timestamp

* seekdb error code: 4344

* Error reason: The timestamp is invalid.

* Solution: Enter a valid timestamp.

## ERROR 4345 (HY000) : dir not empty

* seekdb error code: 4345

* Error reason: The directory is not empty.

* Solution: Check whether the installation directory of seekdb is correct.

## ERROR 4346 (HY000) : schema is not up to date for read

* seekdb error code: 4346

* Error reason: The local schema version is outdated.

* Solution: Contact technical support.

## ERROR 4347 (HY000) : role (string) does not exist

* seekdb error code: 4347

* Error reason: The `ROLE` does not exist.

* Solution: Make sure that the name of the `ROLE` you use is correct.

## ERROR 4348 (HY000) : role '%.\*s' does not exist

* seekdb error code: 4348

* Error reason: A user or `ROLE` with the specified name already exists.

* Solution: Use a different name.

## ERROR 4349 (HY000) : duplicate privilege listed

* seekdb error code: 4349

* Error reason: The GRANT or REVOKE statement specifies duplicate privileges or `ROLE`s.

* Solution: Remove the duplicate privileges or `ROLE`s.

## ERROR 4356 (HY000) : floating point precision is out of range(1 to 126)

* seekdb error code: 4356

* Error reason: The precision of the `BINARY_DOUBLE` data type exceeds the specified range.

* Solution: Reduce the precision.

## ERROR 4357 (HY000) : numeric precision specifier is out of range (1 to 38)

* seekdb error code: 4357

* Error reason: The precision of the `NUMBER` data type exceeds the specified range.

* Solution: Reduce the precision.

## ERROR 4358 (HY000) : numeric scale specifier is out of range (-84 to 127)

* seekdb error code: 4358

* Error reason: The precision of the `NUMBER` data type exceeds the specified range.

* Solution: Reduce the precision.

## ERROR 4361 (HY000) : slog active transaction entries reach maximum

* seekdb error code: 4361

* Error reason: The number of active transactions in the slog exceeds the maximum limit.

* Solution: Contact technical support.

## ERROR 4362 (HY000) : BY ACCESS \| SESSION clause not allowed for NOAUDIT

* seekdb error code: 4362

* Error reason: The `BY ACCESS` or `BY SESSION` clause is not allowed in the `NOAUDIT` statement.

* Solution: Remove the `BY ACCESS` or `BY SESSION` clause.

## ERROR 4364 (HY000) : DDL statement cannot be audited with BY SESSION specified

* seekdb error code: 4364

* Error reason: The DDL statement cannot be audited with the `BY SESSION` option.

* Solution: Remove the `BY SESSION` clause.

## ERROR 4367 (HY000) : The data more than 64M(rpc limit), split into smaller task and retry

* seekdb error code: 4367

* Error reason: When the data size exceeds 64 MB, the execution task needs to be split into smaller granules. This error code is returned to notify the execution scheduler to split and retry.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 4368 (HY000) : cluster %s not exist

* seekdb error code: 4368

* Error reason: When accessing the Config Server to obtain cluster information, the Config Server returns an internal error indicating that the cluster does not exist.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 4370 (HY000) : tde_method parameter is invalid

* seekdb error code: 4370

* Error reason: The value of the `tde_method` parameter is invalid.

* Solution: Check the value of the `tde_method` parameter.

## ERROR 4374 (HY000) : value larger than specified precision allowed for this column

* seekdb error code: 4374

* Error reason: The `precision` of the value exceeds the `precision` defined for the column.

* Solution: Adjust the value or the column definition.

## ERROR 4375 (HY000) : observer has disk error

* seekdb error code: 4375

* Error reason: A storage disk error occurs.

* Solution: Check whether the disk has a fault and replace the corresponding server.

## ERROR 4376 (HY000) : unimplemented feature

* seekdb error code: 4376

* Error reason: The seekdb database does not support this feature.

* Solution: Contact technical support for assistance.

## ERROR 4377 (HY000) : fatal internal error in \[%.\*s\]

* seekdb error code: 4377

* Error reason: An unexpected internal error occurs in the seekdb database, which may be caused by an exception during program execution.

* Solution: Contact technical support for assistance.

## ERROR 4379 (HY000) : heap table has reached max row size, cannot insert anymore

* seekdb error code: 4379

* Error reason: The number of rows that can be inserted into the heap table reaches the upper limit.

* Solution: Create a new table. If needed, you can migrate the data from the original table to the new table.

## ERROR 4381 (HY000) : Not supported, deprecated MySQL feature

* seekdb error code: 4381

* Error reason: The float(m,d) or double(m,d) data type is used to declare a floating-point number with precision.

* Solution: Use the decimal(m,d) data type instead of the float(m,d) or double(m,d) data type to specify a precise decimal number.

## ERROR 4383 (HY000) : transaction id is not ready

* seekdb error code: 4383

* Error reason: The transaction ID allocator has no available ID range.

* Solution: Retry to obtain an ID until the timeout occurs.

## ERROR 4387 (HY000) : Failed to switch resource group

* seekdb error code: 4387
* Compatible MySQL error code: 13937

## ERROR 4388 (HY000) : Unexpected internal error happen, please checkout the internal errcode

* seekdb error code: 4388

* Error reason: An unexpected internal error occurs.

* Solution: Contact technical support for assistance.

## ERROR 4389 (HY000) : Processing time is too long

* seekdb error code: 4389

* Error reason: The task processing time is too long.

* Solution: Internal error code. If this error code is returned, contact technical support for assistance.

## ERROR 4390 (HY000) : Schema of remote server is not refreshed yet

* seekdb error code: 4390

* Error reason: The local or remote schema has not been refreshed. This may be caused by the seekdb database not being fully restarted or an exception.

* Solution: Contact technical support for assistance.

## ERROR 4391（HY000）：ddl sstable version range cross

* seekdb error code: 4391

* Error reason: The DDL SSTable returns a cross version.

* Solution: Contact technical support for assistance.

## ERROR 4392 (HY000) : disk is hung

* seekdb error code: 4392
* Error reason: A disk error occurs.
* Solution: Contact technical support for assistance.

## ERROR 4393 (HY000) : observer start process failure

* seekdb error code: 4393

* Error reason: The observer process fails to start because an internal component or service fails to initialize.

* Solution: Contact technical support for assistance.

## ERROR 4394 (HY000) : observer stop process failure

* seekdb error code: 4394
* Error reason: An error occurs when the observer process exits.
* Solution: Contact technical support for assistance.

## ERROR 4395 (HY000) : observice start process has failure

* seekdb error code: 4395
* Error reason: The observer process fails to start because an internal component or service fails to initialize.
* Solution: Contact technical support for assistance.

## ERROR 4396 (HY000) : Worker thread panic, thread may be terminated or hung

* seekdb error code: 4396
* Error reason: An exception occurs in the worker thread, causing the thread to panic.
* Solution: Contact technical support for assistance.

## ERROR 4400 (HY000) : Autoinc cache's autoinc version is not equal to request's autoinc version

* seekdb error code: 4400
* Error reason: During an operation, the version of the auto-increment column value cache is inconsistent with the version requested.
* Solution:
   1. Check the auto-increment column value version: Verify that the auto-increment column value version is correct and consistent with the requested auto-increment column value version.
   2. Clear the auto-increment column value cache: Try to clear the auto-increment column value cache to regenerate the auto-increment column value.

## ERROR 4401 (HY000) : Client Session need be killed

* seekdb error code: 4401

* Compatible MySQL error code: 4401

* Error reason: The client session needs to be terminated.
* Solution: Confirm whether the client session needs to be terminated and take appropriate measures to terminate the session, such as using the appropriate command or tool to end the client session.

## ERROR 4402 (HY000) : Kill Client Session failed

* seekdb error code: 4402

* Error reason: The operation to terminate the client session failed.

* Solution: Before executing the session termination operation, ensure that the target session is active and can be terminated.

## ERROR 4403 (HY000) : OS params check failed, because the operating system has improper parameter configurations

* seekdb error code: 4403

* Error reason: seekdb detected that the parameter settings of the operating system are unreasonable.

* Solution: Check the error log to identify which parameter is set incorrectly. Refer to the documentation to find the correct range for the parameter and make the necessary adjustments.